@@ -2,11 +2,11 @@
 import mock
 import pytest
 from io import BytesIO
-from lingua.extractors.xml import XMLExtractor
+from lingua.extractors.xml import ChameleonExtractor
 from lingua.extractors.xml import get_python_expressions
 
 
-xml_extractor = XMLExtractor()
+xml_extractor = ChameleonExtractor()
 source = None
 
 
@@ -438,17 +438,17 @@ def test_curly_brace_related_syntax_error():
 
 class Test_get_python_expression(object):
     def test_no_expressions(self):
-        assert list(get_python_expressions('no python here')) == []
+        assert list(get_python_expressions('no python here', 'python')) == []
 
     def test_single_expression(self):
-        assert list(get_python_expressions('${some_python}')) == ['some_python']
+        assert list(get_python_expressions('${some_python}', 'python')) == ['some_python']
 
     def test_two_expressions(self):
-        assert list(get_python_expressions('${one} ${two}')) == ['one', 'two']
+        assert list(get_python_expressions('${one} ${two}', 'python')) == ['one', 'two']
 
     def test_nested_braces(self):
         assert list(get_python_expressions(
-            '''${resource_url(_query={'one': 'one'})}''')) == \
+            '''${resource_url(_query={'one': 'one'})}''', 'python')) == \
             ['''resource_url(_query={'one': 'one'})''']
 
 
